@@ -13,7 +13,7 @@ from terra_geocrud.models import AttachmentCategory, feature_attachment_director
 from terra_geocrud.properties.files import get_storage
 from terra_geocrud.tests import factories
 from terra_geocrud.tests.factories import CrudViewFactory, FeaturePictureFactory, FeatureAttachmentFactory, \
-    RoutingSettingsFactory
+    RoutingSettingsFactory, RoutingInformationFactory
 from .. import models
 from ..properties.schema import sync_layer_schema, sync_ui_schema
 
@@ -214,6 +214,11 @@ class CrudViewPropertyTestCase(TestCase):
         with self.assertRaises(ValidationError):
             prop.clean()
 
+    def test_constraint_not_editable_func(self):
+        prop = CrudViewProperty.objects.create(view=self.crud_view, key="not_editable_func", json_schema={},
+                                               ui_schema={}, editable=False)
+        self.assertIsNotNone(prop)
+
 
 @override_settings(MEDIA_ROOT=TemporaryDirectory().name)
 class FeaturePictureTestCase(TestCase):
@@ -370,3 +375,13 @@ class RoutingSettingsTestCase(TestCase):
                                                label="Other")
         setting.clean()
         self.assertEqual(str(setting), 'Other')
+
+
+class RoutingInformationTestCase(TestCase):
+    @classmethod
+    def setUpTestData(cls):
+        cls.routing_information = RoutingInformationFactory.create()
+
+    def test_str(self):
+        self.assertEqual(str(self.routing_information),
+                         f'Routing infos : {self.routing_information.feature.identifier}')
